###############################################################################
#
# Developed with love
#
#  (c) 2025-2025 Copyright: Sebastian Schwarz 
#
#  This script is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  any later version.
#
#  The GNU General Public License can be found at
#  http://www.gnu.org/copyleft/gpl.html.
#  A copy is found in the textfile GPL.txt and important notices to the license
#  from the author is found in LICENSE.txt distributed with these scripts.
#
#  This script is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#
# $Id$
#
###############################################################################

package FHEM::Bluelink;

use strict;
use warnings;

use GPUtils qw(GP_Import GP_Export);
require FHEM::Devices::Bluelink::Bluelink;

## Import der FHEM Funktionen
#-- Run before package compilation
BEGIN {
 
    # Import from main context
    GP_Import(
        qw(
            readingFnAttributes
          )
    );
}

#-- Export to main context with different name
GP_Export(
    qw(
        Initialize
      )
);

sub Initialize {
    my $hash = shift;

    # Provider
    $hash->{WriteFn}   = \&Write; 

    # Consumer
    $hash->{DefFn}      = 'FHEM::Devices::Bluelink::Bluelink::Define';
    $hash->{UndefFn}    = 'FHEM::Devices::Bluelink::Bluelink::Undef';
    $hash->{SetFn}      = 'FHEM::Devices::Bluelink::Bluelink::Set';
    $hash->{DeleteFn}   = 'FHEM::Devices::Bluelink::Bluelink::Delete';
    $hash->{RenameFn}   = 'FHEM::Devices::Bluelink::Bluelink::Rename'; 
    $hash->{NotifyFn}   = 'FHEM::Devices::Bluelink::Bluelink::Notify';


    $hash->{AttrFn}     = 'FHEM::Devices::Bluelink::Bluelink::Attr';
    $hash->{AttrList} =
       'disable:1 '
      . 'interval '
      . $::readingFnAttributes;
    $hash->{parseParams} = 1;

    return FHEM::Meta::InitMod( __FILE__, $hash );
}

1;

=pod

=item device
=item summary       Modul to control Bluelink Vehicles
=item summary_DE    Modul zur Steuerung von Bluelink Fahrzeugen
=begin html

<a name="Bluelink"></a>
<h3>Bluelink</h3>
<a name="Bluelinkdefine"></a>
<b>Define</b>
<ul><br>
  <code>define &lt;name&gt; Bluelink </code>
  <br><br>
  Example:
  <ul><br>
    <code>define bl Bluelink </code><br>
  </ul> 
  <br><br>
  <a name="Bluelinkreadings"></a>
  <br><br>
  <b>Readings</b>
  <ul>
    <li>1st</li>
    <li>2nd</li>
  </ul>
  <br><br>
  <a name="Bluelinkeset"></a>
  <b>set</b>
  <ul> 
    <li>first</li>
    <li>secibd</li>
  </ul>
  <br><br>
  <a name="Bluelinkeattributes"></a>
  <b>Attributes</b>
  <ul>
    <li>foo</li>
    <li>bar</li>
  </ul>
</ul>

=end html
=begin html_DE

<a name="Bluelink"></a>
<h3>Bluelink</h3>
<br>
<a name="Bluelinkdefine"></a>
<b>Define</b>
<ul><br>
  <code>define &lt;name&gt; Bluelink</code>
  <br><br>
  Beispiel:
  <ul><br>
    <code>define bl Bluelink</code><br>
  </ul> 
  <br><br>
  <a name="Bluelinkreadings"></a>
  <br><br>
  <b>Readings</b>
  <ul> 
    <li>1st</li>
    <li>2nd</li>
  </ul>
  <br><br>
  <a name="Bluelinkset"></a>
  <b>set</b>
  <ul>
    <li>erstens </li>
    <li>zweitens</li> 
  </ul> 
  <br><br>
  <a name="Bluelinkeattributes"></a>
  <b>Attributes</b>
  <ul>
    <li>foo</li>
    <li>bar</li>
  </ul>
 
</ul>

=end html_DE

=for :application/json;q=META.json 73_Bluelink.pm
{
  "abstract": "Modul to control Bluelink",
  "x_lang": {
    "de": {
      "abstract": "Modul zum bedienen des Bluelink"
    }
  },
  "keywords": [
    "fhem-mod-device",
    "fhem-core",
    "Bluelink",
    "Smart"
  ],
  "release_status": "stable",
  "license": "GPL_2",
  "version": "v0.0.1",
  "author": [
    "Sebastian Schwarz <ema@il.local>"
  ],
  "x_fhem_maintainer": [
    "BOFH"
  ],
  "x_fhem_maintainer_github": [
    "NO ONE"
  ],
  "prereqs": {
    "runtime": {
      "requires": {
        "FHEM": 5.00918799,
        "perl": 5.016, 
        "Meta": 0, 
        "HttpUtils": 0,
        "Encode": 0
      },
      "recommends": {
      },
      "suggests": {
      }
    }
  }
}
=end :application/json;q=META.json

=cut
